"use strict";exports.id=2517,exports.ids=[2517],exports.modules={"./src/commands/worker-pool.ts"(o,e,r){r.r(e),r.d(e,{DEFAULT_WORKER_POOL_NAME:()=>l,WORKER_POOL_LABEL_KEY:()=>n,applyWorkerPoolLabel:()=>s,getWorkerPoolName:()=>u,isPoolAssignmentEnabled:()=>t,resolveWorkerPoolName:()=>i});const n="pool",l="default";function t(o){return!0===o.pool||!0===o.singleUse}function i(o){var e;const r=null===(e=o.poolName)||void 0===e?void 0:e.trim();if(void 0!==o.poolName&&(!r||0===r.length))throw new Error("--pool-name cannot be empty");if(o.poolAssignmentEnabled)return null!=r?r:l;if(void 0!==r)throw new Error("--pool-name requires --pool or --single-use")}function s(o,e){return e?[{key:n,value:e},...o.filter((o=>o.key!==n))]:[...o]}function u(o){const e=null==o?void 0:o.find((o=>o.key===n)),r=null==e?void 0:e.value.trim();return r&&r.length>0?r:void 0}}};