"use strict";exports.id=2738,exports.ids=[2738],exports.modules={"./src/commands/update.ts"(t,e,n){n.r(e),n.d(e,{handleUpdate:()=>r});var c=n("./src/analytics.ts"),s=n("./src/commands/update-core.ts");function r(t,e){return n=this,r=arguments,a=function*(t,e,n="agent-cli"){try{const r=e.get();"static"===r.channel&&(process.stdout.write("Skipping update check for static channel\n"),process.exit(0)),yield(0,s.NB)({dashboardClient:t,showProgress:!0,channel:r.channel,isAutoUpdate:!1,product:n}),yield(0,c.PO)(),process.exit(0)}catch(t){throw new Error(`Update failed: ${t instanceof Error?t.message:String(t)}`)}},new((o=void 0)||(o=Promise))((function(t,e){function c(t){try{i(a.next(t))}catch(t){e(t)}}function s(t){try{i(a.throw(t))}catch(t){e(t)}}function i(e){var n;e.done?t(e.value):(n=e.value,n instanceof o?n:new o((function(t){t(n)}))).then(c,s)}i((a=a.apply(n,r||[])).next())}));var n,r,o,a}}};